#
# Conditional build:
%bcond_without	doc		# Sphinx documentation
%bcond_without	tests		# unit tests (and possibly benchmarks)
%bcond_with	benchmarks	# benchmarks

%if %{without tests}
%undefine	with_benchmarks
%endif
%define 	module	greenlet
Summary:	Lightweight in-process concurrent programming
Summary(pl.UTF-8):	Lekkie programowanie równoległe wewnątrz procesu
Name:		python3-%{module}
Version:	3.2.3
Release:	1
License:	MIT, PSF (Stackless Python parts)
Group:		Libraries/Python
#Source0Download: https://pypi.org/simple/greenlet/
Source0:	https://files.pythonhosted.org/packages/source/g/greenlet/%{module}-%{version}.tar.gz
# Source0-md5:	7ad06c6e1f5e16908aa8bbc713531b78
URL:		https://pypi.org/project/greenlet/
BuildRequires:	python3-devel >= 1:3.9
BuildRequires:	python3-setuptools >= 1:40.8.0
BuildRequires:	python3-modules >= 1:3.9
%if %{with tests}
BuildRequires:	python3-objgraph
BuildRequires:	python3-psutil
%endif
%if %{with benchmarks}
BuildRequires:	python3-pyperf
%endif
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
%if %{with doc}
BuildRequires:	python3-furo
# already installed
BuildRequires:	python3-greenlet
BuildRequires:	sphinx-pdg-3
%endif
Requires:	python3-modules >= 1:3.9
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

# -fno-tree-dominator-opts because https://bugzilla.opensuse.org/show_bug.cgi?id=902146
%define		specflags_x32	-fno-tree-dominator-opts

%description
The greenlet package is a spin-off of Stackless, a version of CPython
that supports micro-threads called "tasklets". Tasklets run
pseudo-concurrently (typically in a single or a few OS-level threads)
and are synchronized with data exchanges on "channels".

%description -l pl.UTF-8
Pakiet greenlet to odprysk projektu Stackless - wersji CPythona
obsługującej mikrowątki zwane "taskletami". Tasklety działają
pseudorównolegle (zwykle w jednym lub kilku wątkach na poziomie
systemu operacyjnego) i są synchronizowane przy wymianie danych
poprzez "kanały".

%package devel
Summary:	C development headers for Python 2 greenlet module
Summary(pl.UTF-8):	Pliki nagłówkowe C dla modułu Pythona 2 greenlet
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	python3-devel >= 1:3.9

%description devel
This package contains header files required for C modules development.

%description devel -l pl.UTF-8
Ten pakiet zawiera pliki nagłówkowe potrzebne do tworzenia modułów w
C.

%package apidocs
Summary:	API documentation for Python greenlet module
Summary(pl.UTF-8):	Dokumentacja API modułu Pythona greenlet
Group:		Documentation
BuildArch:	noarch

%description apidocs
API documentation for Python greenlet module.

%description apidocs -l pl.UTF-8
Dokumentacja API modułu Pythona greenlet.

%prep
%setup -q -n greenlet-%{version}

%build
%py3_build

%if %{with tests}
BUILDDIR=$(echo $(pwd)/build-3/lib.linux-*)
PYTHONPATH="$BUILDDIR" \
%{__python3} -m unittest discover greenlet.tests
%endif

%if %{with benchmarks}
# Run the upstream benchmarking suite to further exercise the code:
PYTHONPATH="$BUILDDIR" \
%{__python3} benchmarks/chain.py
%endif

%if %{with doc}
PYTHONPATH=$(echo $(pwd)/build-3/lib.linux-*) \
%{__make} -C docs html \
	SPHINXBUILD=sphinx-build-3
%endif

%install
rm -rf $RPM_BUILD_ROOT

%py3_install

%{__rm} $RPM_BUILD_ROOT%{py3_sitedir}/greenlet/*.[ch]
%{__rm} $RPM_BUILD_ROOT%{py3_sitedir}/greenlet/*.[ch]pp
%{__rm} -r $RPM_BUILD_ROOT%{py3_sitedir}/greenlet/{platform,tests}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc AUTHORS CHANGES.rst LICENSE README.rst
%dir %{py3_sitedir}/greenlet
%attr(755,root,root) %{py3_sitedir}/greenlet/_greenlet.cpython-*.so
%{py3_sitedir}/greenlet/*.py
%{py3_sitedir}/greenlet/__pycache__
%{py3_sitedir}/greenlet-%{version}-py*.egg-info

%files devel
%defattr(644,root,root,755)
%{_includedir}/python%{py3_ver}*/greenlet

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc docs/_build/html/{_modules,_static,*.html,*.js}
%endif
%changelog
* Fri Jun 27 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python3-greenlet.git;a=log;h=master

* Fri Jun 27 2025 Jakub Bogusz <qboosh@pld-linux.org> 07f8b94
- updated to 3.2.3, disable benchmarks by default (slow and segfault somewhere)

* Fri Mar 14 2025 Arkadiusz Miśkiewicz <arekm@maven.pl> fec1107
- Up to 3.1.1

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> 1795a77
- doc/test rebuild for python 3.13

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> 0167de6
- use patch -P

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> fecba33
- python 3.13 rebuild

* Sun Sep 11 2022 Jakub Bogusz <qboosh@pld-linux.org> 13507e0
- updated to 1.1.3
- noarch -apidocs package

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> 9b2773d
- rebuild with tests and docs

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 12ad6bd
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> c760ef9
- rebuild with python 3.10

* Thu Mar 24 2022 Jakub Bogusz <qboosh@pld-linux.org> 7b8a5d6
- updated to 1.1.2 (1.1.x already required by python-gevent in Th)

* Sat Nov 20 2021 Jan Rękorajski <baggins@pld-linux.org> 9c3e8fa
- rebuild with separate debuginfo build-ids

* Thu Mar 04 2021 Arkadiusz Miśkiewicz <arekm@maven.pl> 8c45797
- up to 0.4.17

* Wed Jan 01 2020 Jakub Bogusz <qboosh@pld-linux.org> 4d60538
- added py3.8 patch (deal with time.clock() removed in Python 3.8)
- added apidocs
- release 4

* Wed Oct 30 2019 Arkadiusz Miśkiewicz <arekm@maven.pl> e07b915
- rel 3; fix build without tests

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> dc3c647
- rebuild with python 3.8
- release 2 (by relup.sh)

* Mon Oct 22 2018 Jacek Konieczny <j.konieczny@eggsoft.pl> 0032953
- Version: 0.4.15

* Sun Jul 29 2018 Jakub Bogusz <qboosh@pld-linux.org> 6fa6396
- updated to 0.4.14

* Sun Jul 01 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 874ff60
- release 2 (by relup.sh)

* Mon Mar 05 2018 Jacek Konieczny <j.konieczny@eggsoft.pl> f0135ef
- Version: 0.4.13

* Tue Mar 14 2017 Jakub Bogusz <qboosh@pld-linux.org> d74d10e
- updated to 0.4.12

